//Score: 0 O(n + b^3)
#include <bits/stdc++.h>
//comment the following line for detailed debug messages
#define cerr if (0) cerr

using namespace std;

int aSize, bSize;

//Represents a way to split Pizza into pieces of size A and size B
struct Decomposition {
  int aPieces;
  int bPieces;
  Decomposition(int aPieces = 0, int bPieces = 0);
  int getTotalPizza() const;
  Decomposition& operator*=(const int d);
  friend Decomposition operator*(Decomposition d1, const int d2);
  Decomposition& operator+=(const Decomposition& d);
  friend Decomposition operator+(Decomposition d1, const Decomposition& d2);
  Decomposition& operator-=(const Decomposition& d);
  friend Decomposition operator-(Decomposition d1, const Decomposition& d2);
  friend ostream& operator<<(ostream& out, const Decomposition d);
};

int numBPiecesToReplaceAPieces(int aPieces);
int numAPiecesToReplaceBPieces(int bPieces);
int ceiledDivision(int numerand, int quotient);

//Precomputes all ways to combine pieces of size A and size B up to 2*A*B inclusive
struct AllPossibleSums {
  AllPossibleSums(int A, int B);

  //Find the way to split a number into pieces of A and B that wastes the least amount of Pizza.
  Decomposition getBestDecomposition(int hunger);

private:
  vector<Decomposition> bestDecomposition;
};
  
int main() {
  //Read input
  ios_base::sync_with_stdio(0);
  cin.tie(0);
  int n;
  cin >> n >> aSize >> bSize;
  vector<int> mouseHunger;
  copy_n(istream_iterator<int>(cin), n, back_inserter(mouseHunger));
  
  //Find all ways to combine pieces of A and B up to 2*A*B
  AllPossibleSums decomposer(aSize, bSize);

  //Feed the mice whole Pizzas until they have less than 2*A*B hunger
  int64_t initialPizzasNeeded = 0;
  
  //Count how many mice want a specific amount of Pizza. Even though it is not unique, we can find a distinct decomposition for every amount of Pizza.
  vector<int> decompositionOccurrences(2*aSize*bSize+1, 0);
  for (int i = 0; i < n; i++){
    if (mouseHunger[i] > 2 * aSize * bSize){
      int PizzasToFeed = mouseHunger[i] / (aSize * bSize) - 1;
      mouseHunger[i] -= PizzasToFeed * aSize * bSize;
      cerr << "Feeding mouse " << i << " " << PizzasToFeed << " whole Pizzas to reduce its hunger to " << mouseHunger[i] << endl;
      initialPizzasNeeded += PizzasToFeed;
    }
    decompositionOccurrences[mouseHunger[i]] ++;
  }
  
  //Find a greedy solution that minimizes the Pizza wasted per mouse
  Decomposition totalPiecesNeeded;
  for (int totalPizza = 0; totalPizza < decompositionOccurrences.size(); totalPizza++) {
    if(!decompositionOccurrences[totalPizza]) continue;
    Decomposition mousePizzaAssignment = decomposer.getBestDecomposition(totalPizza);
    totalPiecesNeeded += mousePizzaAssignment * decompositionOccurrences[totalPizza];
    cerr << decompositionOccurrences[totalPizza] << " mice each get " << mousePizzaAssignment << endl;
  }
  
  //Remove as many whole Pizzas as possible
  initialPizzasNeeded += totalPiecesNeeded.aPieces / bSize;
  totalPiecesNeeded.aPieces %= bSize;
  initialPizzasNeeded += totalPiecesNeeded.bPieces / aSize;
  totalPiecesNeeded.bPieces %= aSize;
  //If any pieces are left, we will need at least one more Pizza, possibly two more Pizzas.
  cerr << "Remaining hunger after feeding " << initialPizzasNeeded << " Pizzas: " << totalPiecesNeeded << endl;
  initialPizzasNeeded += totalPiecesNeeded.getTotalPizza() > 0;
  
  cerr << "At least " << initialPizzasNeeded << " Pizzas are necessary to feed the mice." << endl;
  
  //We now want to find a set of Pizza replacements that brings the remaining A pieces or B pieces to zero.
  //So we look at all possible replacements for every distinct amount of hunger.
  //Over all amounts of hunger, we find for every possible replacement how many A pieces are replaced.
  //Then we store just how many of these replacements of a given amount of A pieces are possible.
  //We only need to store the count, since there is a clear minimum number of B sized pieces required to replace a fixed number of A sized pieces.
  //This gives us the set of replacement operations that we can apply in order to try to optimize the greedy solution.
  vector<int> deltaAOccurrences(2 * bSize + 1, 0);
  for (int totalPizza = 0; totalPizza < decompositionOccurrences.size(); totalPizza++) {
    if (!decompositionOccurrences[totalPizza]) continue;
    Decomposition decomposition = decomposer.getBestDecomposition(totalPizza);
    //Iterate all possible ways to replace this decomposition by changing A sized pieces into B sized pieces
    for (int aPiecesToReplace = 0; aPiecesToReplace <= bSize; aPiecesToReplace++) {
      Decomposition alternativeDecomposition = decomposition;
      alternativeDecomposition.aPieces -= aPiecesToReplace;
      alternativeDecomposition.bPieces += numBPiecesToReplaceAPieces(aPiecesToReplace);
      //If A pieces are negative, simply treat it as replacing an entire Pizza worth of B pieces by A pieces
      if (alternativeDecomposition.aPieces < 0) {
	alternativeDecomposition.aPieces += bSize;
	alternativeDecomposition.bPieces -= aSize;
      }
      //Make sure the previous step doesn't accidentally remove more B pieces than are available
      if (alternativeDecomposition.bPieces < 0) continue;
      Decomposition change = alternativeDecomposition - decomposition;
      deltaAOccurrences[change.aPieces + bSize] += decompositionOccurrences[totalPizza]; 
    }
  }
  
  //We can now use a DP to apply all of the replacement operations that we discovered.
  //The DP table stores the minimum number of B pieces required to feed all mice if we have a given number of A pieces available.
  //We start out knowing the solution only for the greedy case from before.
  //Then we repeatedly try to find operations that minimize the numbers of B pieces needed to satisfy a given number of A pieces
  //Each operation works as: DP[aPieces] = min(DP[aPieces], DP[aPieces+aPiecesAdded] + bPiecesAdded), with either the A or B pieces being negative
  //The DP table only spans [0, B], since we're not interested in solutions that use less than 0 extra pieces.
  //Any solution that would use more than B A sized pieces would already use more than a single Pizza.
  vector<int> numBPiecesToFeedMiceGivenXAPieces(bSize + 1, aSize + 1);
  //Initialize with the greedy solution that we found before.
  numBPiecesToFeedMiceGivenXAPieces[totalPiecesNeeded.aPieces] = totalPiecesNeeded.bPieces;
  //Keep two arrays to cache the results of the previous iteration. 
  vector<int> newNumBPiecesToFeedMiceGivenXAPieces(numBPiecesToFeedMiceGivenXAPieces);
  for (int j = 0; j < deltaAOccurrences.size(); j++){
    if (!deltaAOccurrences[j]) continue;
    const int deltaA = j - bSize;
    //Iterate through all previously counted ways of replacing A pieces by B pieces (or vice versa when values are negative).
    Decomposition change(deltaA, numBPiecesToReplaceAPieces(-deltaA));
    //For every change we need to iterate at most B^2 times to update the whole table
    for (int it = 0; it < min(bSize, deltaAOccurrences[j]); it++){
      for (int aPieces = max(0, -change.aPieces); aPieces  <= bSize - max(0, change.aPieces); aPieces++){
	//Swap change.aPieces for -change.bPieces or vice versa
	const int newBPieces = numBPiecesToFeedMiceGivenXAPieces[aPieces] + change.bPieces;
	if (newBPieces < numBPiecesToFeedMiceGivenXAPieces[aPieces + change.aPieces]){
	  newNumBPiecesToFeedMiceGivenXAPieces[aPieces + change.aPieces] = newBPieces;
	}
      }
      numBPiecesToFeedMiceGivenXAPieces = newNumBPiecesToFeedMiceGivenXAPieces;
    }
  }

  //We found a way to only use a single Pizza if the number of B pieces required when using 0 A pieces is less or equal to a whole Pizza
  //or if there is a way to use 0 B pieces while still using less or equal to a whole Pizza worth of A pieces
  int bestBReplacement = *min_element(numBPiecesToFeedMiceGivenXAPieces.begin(), numBPiecesToFeedMiceGivenXAPieces.end());
  if (bestBReplacement <= 0 || numBPiecesToFeedMiceGivenXAPieces[0] <= aSize){
    cout << initialPizzasNeeded << endl;
  }else{
    cout << initialPizzasNeeded + 1 << endl;
  }
}

//AllPossibleSums IMPL

//Store all possible sums from 0 to 2*A*B
AllPossibleSums::AllPossibleSums(int A, int B) : bestDecomposition(2*A*B + 1, {-1, -1}) {
  Decomposition decomposition;
  for (decomposition.aPieces = 0; decomposition.aPieces * A <= 2 * A * B; decomposition.aPieces++){
    for (decomposition.bPieces = 0; decomposition.getTotalPizza() <= 2 * A * B; decomposition.bPieces++){
      bestDecomposition[decomposition.getTotalPizza()] = decomposition;
    }
  }
}

//Return the current decomposition, or if it doesn't exist, get the next decomposition with more Pizza and cache it.
Decomposition AllPossibleSums::getBestDecomposition(int hunger){
  if (bestDecomposition[hunger].aPieces < 0) {
    bestDecomposition[hunger] = getBestDecomposition(hunger + 1);
  }
  return bestDecomposition[hunger];
}

//Decomposition IMPL

Decomposition::Decomposition(int aPieces, int bPieces) : aPieces(aPieces), bPieces(bPieces) {
}

int Decomposition::getTotalPizza() const {
  return aSize * aPieces + bSize * bPieces;
}

Decomposition& Decomposition::operator+=(const Decomposition& d) {
  aPieces += d.aPieces;
  bPieces += d.bPieces;
  return *this;
}

Decomposition operator+(Decomposition d1, const Decomposition& d2) {
  d1 += d2;
  return d1;
}

Decomposition& Decomposition::operator-=(const Decomposition& d) {
  aPieces -= d.aPieces;
  bPieces -= d.bPieces;
  return *this;
}

Decomposition operator-(Decomposition d1, const Decomposition& d2) {
  d1 -= d2;
  return d1;
}

Decomposition& Decomposition::operator*=(const int d) {
  aPieces *= d;
  bPieces *= d;
  return *this;
}

Decomposition operator*(Decomposition d1, const int d2) {
  d1 *= d2;
  return d1;
}

ostream& operator<<(ostream& out, const Decomposition d) {
  out << d.getTotalPizza() << " grams of Pizza, split into " << d.aPieces << " pieces of A = " << aSize << " grams and " << d.bPieces << " pieces of B = " << bSize << " grams.";
  return out;
}

//Helpers

int numBPiecesToReplaceAPieces(int aPieces){
  return ceiledDivision(aPieces * aSize, bSize);
}

int numAPiecesToReplaceBPieces(int bPieces){
  return ceiledDivision(bPieces * bSize, aSize);
}

int ceiledDivision(int numerand, int quotient){
  if (numerand < 0) return numerand / quotient;
  return (numerand + quotient - 1) / quotient;
}
