// score: 60
// faster dp solution
// O(n B^2) dp solution with some heuristics that make it O(n B)
#include <bits/stdc++.h>
using namespace std;

constexpr int inf = 1e9;
pair<int, int>& operator+=(pair<int, int> &a, pair<int, int> const&b){
    a.first += b.first;
    a.second += b.second;
    return a;
}
pair<int, int> operator+(pair<int, int> a, pair<int, int> const&b){
    a+=b;
    return a;
}
int64_t cdiv(int64_t a, int64_t b){
    assert(0 < b);
    if(a > 0) return (a + b-1)/b;
    return a/b;
}
template<typename T>
bool xmin(T&a, T const&b){
    if(b < a){
        a = b;
        return true;
    } else {
        return false;
    }
};
struct Decomp{
    Decomp(int A_, int B_) : A(A_), B(B_), U(2*A*B+1), pre(U, {-1, -1}), up(U){
        for(int i=0; i <= min(B-1, U/A); ++i){
            for(int j=0; j <= U/B; ++j){
                const int r = i*A + j*B;
                if(r < U){
                    pre[r] = make_pair(i, j);
                }
            }
        }
        assert(pre[U-1].first != -1);
        for(int i=U-1; i>=0; --i){
            if(pre[i].first == -1) up[i] = up[i+1];
            else up[i] = i;
        }
    }
    pair<int, int> operator()(int x) const {
        if(x >= 2*A*B){
            int a = max(0, x / (A*B)-1);
            return operator()(x - a*A*B) + make_pair(0, a*A);
        }
        auto ret = pre[up[x]];
        assert(ret.first != -1);
        return ret;
    }
    int A, B, U;
    vector<pair<int, int> > pre;
    vector<int> up;
};

void solve(){
    // start with greed
    int n, A, B;
    cin >> n >> A >> B;
    Decomp de(A, B);
    vector<int> v(n);
    int64_t add = 0;
    for(auto &e:v) {
        cin >> e;
        if(e > 2*A*B){
            int x = e/(A*B)-2;
            e -= x*A*B;
            add += x;
        }
    }
    sort(v.begin(), v.end());
    pair<int64_t, int64_t> cnt;
    for(auto const&e:v){
        auto tmp = de(e);
        cnt.first += tmp.first;
        cnt.second += tmp.second;
    }
    cerr << "total: " << accumulate(v.begin(), v.end(), 0) << "\n";
    int64_t ans = cdiv(cnt.first, B) + cdiv(cnt.second, A);
    cerr << "initial: " << cnt.first << "/" << cnt.second << " -> " << cnt.first*A+cnt.second*B << " / " << A*B << "\n";
    // do improvement dp
    vector<int> dp(B, 0); // previous dp
    auto dp2 = dp; // next dp
    bool did = true;
    
    auto cand = [&](int da, int db){
        if(da < 0){
            da += B;
            db -= A;
        }
        for(int i=0; i<B-da; ++i){
            const int j = i+da;
            if(dp2[j] > dp[i] + db){
                dp2[j] = dp[i] + db;
                did = true;
            }
        }
        for(int i=B-da; i<B; ++i){
            const int j = i+da-B;
            if(dp2[j] > dp[i] + db + A){
                dp2[j] = dp[i] + db + A;
                did = true;
            }
        }
    };
    
    for(int i=0; i<n; ++i){
        auto const&e = v[i];
        if(!did && e == v[i-1]) continue;
        did = false;
        auto start = de(e);
        auto test = [&](pair<int, int> const& ab){
            auto [a, b] = ab;
            int da = a - start.first, db = b - start.second;
            if(abs(da) >= B){
                const int x = da/B;
                da -= x*B;
                db += x*A;
            }
            if(da < 0){
                da += B;
                db -= A;
            }
            cand(da, db);
        };
        // try next 3 improvements
        for(int it=0, u=e;it<3;++it){
            auto now = de(u+1);
            assert(A*now.first + B*now.second > u);
            test(now);
            u = A*now.first+B*now.second;
        }
        // try only A or only B
        test({cdiv(e, A), 0});
        test({0, cdiv(e, B)});
        copy(dp2.begin(), dp2.end(), dp.begin());
    }
    for(int i=0; i<B; ++i){
        xmin(ans, cdiv(cnt.first+i, B)+cdiv(cnt.second+dp[i], A));
    }
    cout << add+ans << "\n";
}

signed main(){
    int T = 1;
    //cin >> T;
    for(int it=0; it<T; ++it) solve();
}
